faker\_file.providers.mp3\_file.generators package
==================================================

Submodules
----------

faker\_file.providers.mp3\_file.generators.edge\_tts\_generator module
----------------------------------------------------------------------

.. automodule:: faker_file.providers.mp3_file.generators.edge_tts_generator
   :members:
   :undoc-members:
   :show-inheritance:

faker\_file.providers.mp3\_file.generators.gtts\_generator module
-----------------------------------------------------------------

.. automodule:: faker_file.providers.mp3_file.generators.gtts_generator
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: faker_file.providers.mp3_file.generators
   :members:
   :undoc-members:
   :show-inheritance:
